@@ -6,7 +6,7 @@ from numpy import array, vstack, zeros
 
 win_s = 512                 # fft size
 hop_s = win_s / 4           # hop size
-n_filters = 40
+n_filters = 40              # must be 40 for mfcc
 n_coeffs = 13
 samplerate = 44100
 
@@ -24,7 +24,7 @@ samplerate = s.samplerate
 p = pvoc(win_s, hop_s)
 m = mfcc(win_s, n_filters, n_coeffs, samplerate)
 
-mfccs = zeros([13,])
+mfccs = zeros([n_coeffs,])
 frames_read = 0
 while True:
     samples, read = s()
