@@ -18,8 +18,10 @@
 
 */
 
-#ifdef __APPLE__
 #include "config.h"
+
+#ifdef HAVE_SOURCE_APPLE_AUDIO
+
 #include "aubio_priv.h"
 #include "fvec.h"
 #include "fmat.h"
@@ -58,8 +60,26 @@ aubio_source_apple_audio_t * new_aubio_source_apple_audio(char_t * path, uint_t
 {
   aubio_source_apple_audio_t * s = AUBIO_NEW(aubio_source_apple_audio_t);
 
+  if (path == NULL) {
+    AUBIO_ERROR("source_apple_audio: Aborted opening null path\n");
+    goto beach;
+  }
+
+  if ( (sint_t)block_size <= 0 ) {
+    AUBIO_ERROR("source_apple_audio: Can not open %s with null or negative block_size %d\n",
+        path, block_size);
+    goto beach;
+  }
+
+  if ( (sint_t)samplerate < 0 ) {
+    AUBIO_ERROR("source_apple_audio: Can not open %s with negative samplerate %d\n",
+        path, samplerate);
+    goto beach;
+  }
+
   s->block_size = block_size;
   s->samplerate = samplerate;
+  s->path = path;
 
   if ( aubio_source_apple_audio_open ( s, path ) ) {
     goto beach;
@@ -137,7 +157,7 @@ uint_t aubio_source_apple_audio_open (aubio_source_apple_audio_t *s, char_t * pa
     AUBIO_ERROR("source_apple_audio: Failed opening %s, "
         "error in ExtAudioFileSetProperty (%s)\n", s->path,
         getPrintableOSStatusError(errorstr, err));
-#if 1
+#if 0
   // print client and format descriptions
   AUBIO_DBG("Opened %s\n", s->path);
   AUBIO_DBG("file/client Format.mFormatID:        : %3c%c%c%c / %c%c%c%c\n",
@@ -278,19 +298,56 @@ void del_aubio_source_apple_audio(aubio_source_apple_audio_t * s){
 }
 
 uint_t aubio_source_apple_audio_seek (aubio_source_apple_audio_t * s, uint_t pos) {
-  // after a short read, the bufferList size needs to resetted to prepare for a full read
-  AudioBufferList *bufferList = &s->bufferList;
-  bufferList->mBuffers[0].mDataByteSize = s->block_size * s->channels * sizeof (short);
+  OSStatus err = noErr;
+  if ((sint_t)pos < 0) {
+    AUBIO_ERROR("source_apple_audio: error while seeking in %s "
+        "(can not seek at negative position %d)\n",
+        s->path, pos);
+    err = -1;
+    goto beach;
+  }
+  // check if we are not seeking out of the file
+  SInt64 fileLengthFrames = 0;
+  UInt32 propSize = sizeof(fileLengthFrames);
+  ExtAudioFileGetProperty(s->audioFile,
+      kExtAudioFileProperty_FileLengthFrames, &propSize, &fileLengthFrames);
   // compute position in the source file, before resampling
   smpl_t ratio = s->source_samplerate * 1. / s->samplerate;
   SInt64 resampled_pos = (SInt64)ROUND( pos * ratio );
-  OSStatus err = ExtAudioFileSeek(s->audioFile, resampled_pos);
+  if (resampled_pos > fileLengthFrames) {
+    AUBIO_ERR("source_apple_audio: trying to seek in %s at pos %d, "
+        "but file has only %d frames\n",
+        s->path, pos, (uint_t)(fileLengthFrames / ratio));
+    err = -1;
+    goto beach;
+  }
+  // after a short read, the bufferList size needs to resetted to prepare for a full read
+  AudioBufferList *bufferList = &s->bufferList;
+  bufferList->mBuffers[0].mDataByteSize = s->block_size * s->channels * sizeof (short);
+  // do the actual seek
+  err = ExtAudioFileSeek(s->audioFile, resampled_pos);
   if (err) {
     char_t errorstr[20];
     AUBIO_ERROR("source_apple_audio: error while seeking %s at %d "
         "in ExtAudioFileSeek (%s)\n", s->path, pos,
         getPrintableOSStatusError(errorstr, err));
   }
+#if 0
+  // check position after seek
+  {
+    SInt64 outFrameOffset = 0;
+    err = ExtAudioFileTell(s->audioFile, &outFrameOffset);
+    if (err) {
+      char_t errorstr[20];
+      AUBIO_ERROR("source_apple_audio: error while seeking %s at %d "
+          "in ExtAudioFileTell (%s)\n", s->path, pos,
+          getPrintableOSStatusError(errorstr, err));
+    }
+    AUBIO_DBG("source_apple_audio: asked seek at %d, tell got %d\n",
+        pos, (uint_t)(outFrameOffset / ratio + .5));
+  }
+#endif
+beach:
   return err;
 }
 
@@ -302,4 +359,4 @@ uint_t aubio_source_apple_audio_get_channels(aubio_source_apple_audio_t * s) {
   return s->channels;
 }
 
-#endif /* __APPLE__ */
+#endif /* HAVE_SOURCE_APPLE_AUDIO */
