@@ -151,27 +151,27 @@ beach:
 
 void aubio_source_sndfile_do(aubio_source_sndfile_t * s, fvec_t * read_data, uint_t * read){
   uint_t i,j, input_channels = s->input_channels;
-  /* do actual reading */
+  /* read from file into scratch_data */
   sf_count_t read_samples = sf_read_float (s->handle, s->scratch_data, s->scratch_size);
 
-  smpl_t *data;
-
+  /* where to store de-interleaved data */
+  smpl_t *ptr_data;
 #ifdef HAVE_SAMPLERATE
   if (s->ratio != 1) {
-    data = s->input_data->data;
+    ptr_data = s->input_data->data;
   } else
 #endif /* HAVE_SAMPLERATE */
   {
-    data = read_data->data;
+    ptr_data = read_data->data;
   }
 
   /* de-interleaving and down-mixing data  */
   for (j = 0; j < read_samples / input_channels; j++) {
-    data[j] = 0;
+    ptr_data[j] = 0;
     for (i = 0; i < input_channels; i++) {
-      data[j] += s->scratch_data[input_channels*j+i];
+      ptr_data[j] += s->scratch_data[input_channels*j+i];
     }
-    data[j] /= (smpl_t)input_channels;
+    ptr_data[j] /= (smpl_t)input_channels;
   }
 
 #ifdef HAVE_SAMPLERATE
@@ -184,7 +184,7 @@ void aubio_source_sndfile_do(aubio_source_sndfile_t * s, fvec_t * read_data, uin
 
   if (*read < s->hop_size) {
     for (j = *read; j < s->hop_size; j++) {
-      data[j] = 0;
+      read_data->data[j] = 0;
     }
   }
 
@@ -195,17 +195,17 @@ void aubio_source_sndfile_do_multi(aubio_source_sndfile_t * s, fmat_t * read_dat
   /* do actual reading */
   sf_count_t read_samples = sf_read_float (s->handle, s->scratch_data, s->scratch_size);
 
-  smpl_t **data;
-
+  /* where to store de-interleaved data */
+  smpl_t **ptr_data;
 #ifdef HAVE_SAMPLERATE
   if (s->ratio != 1) {
-    AUBIO_ERR("source_sndfile: no multi channel resampling yet");
+    AUBIO_ERR("source_sndfile: no multi channel resampling yet\n");
     return;
-    //data = s->input_data->data;
+    //ptr_data = s->input_data->data;
   } else
 #endif /* HAVE_SAMPLERATE */
   {
-    data = read_data->data;
+    ptr_data = read_data->data;
   }
 
   if (read_data->height < input_channels) {
@@ -213,7 +213,7 @@ void aubio_source_sndfile_do_multi(aubio_source_sndfile_t * s, fmat_t * read_dat
     // channels of the file, de-interleaving data
     for (j = 0; j < read_samples / input_channels; j++) {
       for (i = 0; i < read_data->height; i++) {
-        data[i][j] = (smpl_t)s->scratch_data[j * input_channels + i];
+        ptr_data[i][j] = (smpl_t)s->scratch_data[j * input_channels + i];
       }
     }
   } else {
@@ -221,7 +221,7 @@ void aubio_source_sndfile_do_multi(aubio_source_sndfile_t * s, fmat_t * read_dat
     // channel from the file to the destination matrix, de-interleaving data
     for (j = 0; j < read_samples / input_channels; j++) {
       for (i = 0; i < input_channels; i++) {
-        data[i][j] = (smpl_t)s->scratch_data[j * input_channels + i];
+        ptr_data[i][j] = (smpl_t)s->scratch_data[j * input_channels + i];
       }
     }
   }
@@ -231,7 +231,7 @@ void aubio_source_sndfile_do_multi(aubio_source_sndfile_t * s, fmat_t * read_dat
     // of the file to each additional channels, de-interleaving data
     for (j = 0; j < read_samples / input_channels; j++) {
       for (i = input_channels; i < read_data->height; i++) {
-        data[i][j] = (smpl_t)s->scratch_data[j * input_channels + (input_channels - 1)];
+        ptr_data[i][j] = (smpl_t)s->scratch_data[j * input_channels + (input_channels - 1)];
       }
     }
   }
@@ -247,7 +247,7 @@ void aubio_source_sndfile_do_multi(aubio_source_sndfile_t * s, fmat_t * read_dat
   if (*read < s->hop_size) {
     for (i = 0; i < read_data->height; i++) {
       for (j = *read; j < s->hop_size; j++) {
-        data[i][j] = 0.;
+        read_data->data[i][j] = 0.;
       }
     }
   }
@@ -264,7 +264,17 @@ uint_t aubio_source_sndfile_get_channels(aubio_source_sndfile_t * s) {
 
 uint_t aubio_source_sndfile_seek (aubio_source_sndfile_t * s, uint_t pos) {
   uint_t resampled_pos = (uint_t)ROUND(pos / s->ratio);
-  return sf_seek (s->handle, resampled_pos, SEEK_SET);
+  sf_count_t sf_ret = sf_seek (s->handle, resampled_pos, SEEK_SET);
+  if (sf_ret == -1) {
+    AUBIO_ERR("source_sndfile: Failed seeking %s at %d: %s\n", s->path, pos, sf_strerror (NULL));
+    return AUBIO_FAIL;
+  }
+  if (sf_ret != resampled_pos) {
+    AUBIO_ERR("source_sndfile: Tried seeking %s at %d, but got %d: %s\n",
+        s->path, resampled_pos, (uint_t)sf_ret, sf_strerror (NULL));
+    return AUBIO_FAIL;
+  }
+  return AUBIO_OK;
 }
 
 uint_t aubio_source_sndfile_close (aubio_source_sndfile_t *s) {
@@ -272,7 +282,7 @@ uint_t aubio_source_sndfile_close (aubio_source_sndfile_t *s) {
     return AUBIO_FAIL;
   }
   if(sf_close(s->handle)) {
-    AUBIO_ERR("source_sndfile: Error closing file %s: %s", s->path, sf_strerror (NULL));
+    AUBIO_ERR("source_sndfile: Error closing file %s: %s\n", s->path, sf_strerror (NULL));
     return AUBIO_FAIL;
   }
   return AUBIO_OK;
