@@ -23,7 +23,7 @@ int main (int argc, char **argv)
     return err;
   }
 
-#ifdef HAVE_AVCODEC
+#ifdef HAVE_LIBAV
   uint_t samplerate = 0;
   uint_t hop_size = 256;
   uint_t n_frames = 0, read = 0;
@@ -52,9 +52,9 @@ int main (int argc, char **argv)
   del_fvec (vec);
   del_aubio_source_avcodec (s);
 beach:
-#else
+#else /* HAVE_LIBAV */
   err = 3;
   PRINT_ERR("aubio was not compiled with aubio_source_avcodec\n");
-#endif /* HAVE_AVCODEC */
+#endif /* HAVE_LIBAV */
   return err;
 }
